# TODO

-   Properly setup linters and test runners
-   Use aiohttp for fetching bulk data objects
-   Documentation
-   Do we want to support older versions of Python? It would be friendly but it makes the type annotations uglier...
